import {
  HireType,
  SupplierProfitUintText,
  OrderRebateModeText,
  CycleTypeEnumUnitText,
  SalaryTimeTypeEnumUnit,
} from '@12333/constants';
import { filterJoin } from '@12333/utils';

export class OrderUtils {
  static getHireNumber(hireType: HireType, hireNumber?: number, hireEndNumber?: number) {
    if (hireNumber) {
      return hireType === HireType.hireNumber ? hireNumber : `${hireNumber}~${hireEndNumber}`;
    }
    return 0;
  }

  static getSupplierRefund(row: API.OrderSupplierRefundInfo[]) {
    if (!row?.length) {
      return '未填写供应商利润';
    }
    const item = row[0];
    return `${item.supplierProfit}${
      CycleTypeEnumUnitText[item.supplierProfitUint] ?? '未填写供应商利润'
    }`;
  }

  static getRebateModeText(row: API.OrderSupplierRefundInfo[]) {
    if (!row?.length) {
      return '';
    }
    const item = row[0];
    return `${OrderRebateModeText[item.rebateMode] ?? ''}`;
  }

  static getIntegratedSalary<T extends { salaryTimeType?: number; integratedSalary?: string }>(
    row: T
  ) {
    return `${row.integratedSalary ?? ''}${SalaryTimeTypeEnumUnit[row.salaryTimeType] ?? ''}`;
  }

  static getAddress<T extends { provinceName?: string; cityName?: string; countyName?: string }>(
    row: T
  ) {
    return filterJoin([row.provinceName ?? '', row.cityName ?? '', row.countyName ?? '']);
  }
}
